<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="refresh" content="0; url={{ redirect_url }}">
    <title>Redirecting...</title>
</head>
<body>
    <p>Redirecting to <a href="{{ redirect_url }}">{{ redirect_title }}</a>...</p>
</body>
</html>
